Skip to contents

Returns the API entry for one specific version of an API.

Usage

get_api(provider, version, max_reqs = Inf, max_tries_per_req = 3)

req_get_api(provider, version)

tidy_policy_get_api()

Arguments

provider

(length-1 character)

version

(length-1 character)

max_reqs

(length-1 integer) The maximum number of separate requests to perform. Passed on to nectar::req_perform_opinionated().

max_tries_per_req

(length-1 integer) The maximum number of times to attempt each individual request. Passed on to nectar::req_perform_opinionated().

Value

get_api(): The API response.

req_get_api(): (httr2_request) A httr2::request() object.

tidy_policy_get_api(): (nectar_tidy_policy) A list like the ones returned by nectar::tidy_policy_prepare().